==> taler-wallet-v0.9.3.tar.gz: taler-wallet-v0.9.3/packages/demobank-ui/src/stories.test.ts <==
/*
 This file is part of GNU Taler
 (C) 2022 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */
import { AccessToken, TalerCorebankApi, setupI18n } from "@gnu-taler/taler-util";
import { parseGroupImport } from "@gnu-taler/web-util/browser";
import * as tests from "@gnu-taler/web-util/testing";
import * as components from "./components/index.examples.js";
import * as pages from "./pages/index.stories.js";

import { ComponentChildren, VNode, h as create } from "preact";
import { BackendStateProviderTesting } from "./context/backend.js";
import { BankCoreApiProviderTesting } from "./context/config.js";

setupI18n("en", { en: {} });

describe("All the examples:", () => {
  const cms = parseGroupImport({ pages, components });
  cms.forEach((group) => {
    describe(`Example for group "${group.title}:"`, () => {
      group.list.forEach((component) => {
        describe(`Component ${component.name}:`, () => {
          component.examples.forEach((example) => {
            it(`should render example: ${example.name}`, () => {
              tests.renderUI(example.render, DefaultTestingContext);
            });
          });
        });
      });
    });
  });
});

function DefaultTestingContext({
  children,
}: {
  children: ComponentChildren;
}): VNode {
  const ctx1 = create(BackendStateProviderTesting, {
    children,
    state: {
      status: "loggedIn",
      username: "test",
      token: "pwd" as AccessToken,
      isUserAdministrator: false,
    },
  });
  const cfg: TalerCorebankApi.Config = {
    name: "libeufin-bank",
    allow_deletions: true,
    allow_registrations: true,
    allow_conversion: true,
    currency: "ASR",
    currency_specification: {
      name: "ARS",
      alt_unit_names: {},
      num_fractional_input_digits: 2,
      num_fractional_normal_digits: 2,
      num_fractional_trailing_zero_digits: 2,
    },
    version: "1:0:0",
  }
  const ctx2 = create(BankCoreApiProviderTesting, {
    children: ctx1,
    state: cfg,
    url: "http://localhost",
  });
  return ctx2;
}

==> taler-wallet-v0.9.4a.tar.gz: taler-wallet-v0.9.4a/packages/demobank-ui/src/stories.test.ts <==
/*
 This file is part of GNU Taler
 (C) 2022-2024 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */
import {
  AccessToken,
  AmountString,
  TalerCorebankApi,
  setupI18n,
} from "@gnu-taler/taler-util";
import { parseGroupImport } from "@gnu-taler/web-util/browser";
import * as tests from "@gnu-taler/web-util/testing";
import * as components from "./components/index.examples.js";
import * as pages from "./pages/index.stories.js";

import { ComponentChildren, VNode, h as create } from "preact";
import { BackendStateProviderTesting } from "./context/backend.js";
import { BankCoreApiProviderTesting } from "./context/config.js";

setupI18n("en", { en: {} });

describe("All the examples:", () => {
  const cms = parseGroupImport({ pages, components });
  cms.forEach((group) => {
    describe(`Example for group "${group.title}:"`, () => {
      group.list.forEach((component) => {
        describe(`Component ${component.name}:`, () => {
          component.examples.forEach((example) => {
            it(`should render example: ${example.name}`, () => {
              tests.renderUI(example.render, DefaultTestingContext);
            });
          });
        });
      });
    });
  });
});

function DefaultTestingContext({
  children,
}: {
  children: ComponentChildren;
}): VNode {
  const ctx1 = create(BackendStateProviderTesting, {
    children,
    state: {
      status: "loggedIn",
      username: "test",
      token: "pwd" as AccessToken,
      isUserAdministrator: false,
    },
  });
  const cfg: TalerCorebankApi.Config = {
    name: "libeufin-bank",
    allow_deletions: true,
    supported_tan_channels: [],
    allow_registrations: true,
    allow_conversion: true,
    allow_edit_cashout_payto_uri: false,
    allow_edit_name: false,
    currency: "ASR",
    currency_specification: {
      name: "ARS",
      alt_unit_names: {},
      num_fractional_input_digits: 2,
      num_fractional_normal_digits: 2,
      num_fractional_trailing_zero_digits: 2,
    },
    default_debit_threshold: "ARS:10" as AmountString,
    version: "1:0:0",
  };
  const ctx2 = create(BankCoreApiProviderTesting, {
    children: ctx1,
    state: cfg,
    url: "http://localhost",
  });
  return ctx2;
}
